Interface: PointPrefixedOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: PointPrefixedOptions

## # Properties

### # pointBackgroundColor

• pointBackgroundColor: `Color`

The fill color for points.

#### # Defined in

index.esm.d.ts:1919
(opens new window)

### # pointBorderColor

• pointBorderColor: `Color`

The border color for points.

#### # Defined in

index.esm.d.ts:1923
(opens new window)

### # pointBorderWidth

• pointBorderWidth: `number`

The width of the point border in pixels.

#### # Defined in

index.esm.d.ts:1927
(opens new window)

### # pointHitRadius

• pointHitRadius: `number`

The pixel size of the non-displayed point that reacts to mouse events.

#### # Defined in

index.esm.d.ts:1931
(opens new window)

### # pointRadius

• pointRadius: `number`

The radius of the point shape. If set to 0, the point is not rendered.

#### # Defined in

index.esm.d.ts:1935
(opens new window)

### # pointRotation

• pointRotation: `number`

The rotation of the point in degrees.

#### # Defined in

index.esm.d.ts:1939
(opens new window)

### # pointStyle

• pointStyle: `PointStyle`

Style of the point.

#### # Defined in

index.esm.d.ts:1943
(opens new window)